@@ -22,10 +22,12 @@ stored as BSON.
 usage: bsondump FILE
 """
 
+from __future__ import absolute_import, print_function
+
 from pprint import pprint
 import sys
 
-import anybson as bson
+from oops_datedir_repo import anybson as bson
 
 
 def main(argv=None):
